@@ -64,7 +64,7 @@ def node2dict(node):
     values['state'] = NODE_STATES[values['state']]
 
     for field in 'image', 'size':
-        if 'field' in values and values[field]:
+        if field in values and values[field]:
             values[field] = values[field].name
 
     for field in 'public_ips', 'private_ips':
@@ -238,6 +238,11 @@ class BaseCloud(object):
         nodes."""
         return [ node2dict(node) for node in self.driver.list_nodes() ]
 
+    def list_sizes(self):
+        """Return a list of strings representing the available instance
+        size names."""
+        return [ size.name for size in self.driver.list_sizes() ]
+
     def list_images(self, limit=None, keyword=''):
         """Return a list of VM images available on this cloud."""
         images = [ image for image in self.driver.list_images() 
@@ -248,8 +253,8 @@ class BaseCloud(object):
 
         return images
 
-    def deploy(self, size_idx=0, location_idx=0, name='test'):
+    def deploy(self, image_id, size_idx=0, location_idx=0, name='test'):
         """Deploy a VM instance on this cloud. This method is not implemented
-        here, it has to be specialized by the classes implementing specific cloud
-        providers."""
+        here, it has to be specialized by the classes implementing specific 
+        cloud providers."""
         raise NotImplementedError()
